@@ -11,6 +11,7 @@ from rich.table import Table
 from ..utils.auth import AuthManager
 from ..utils.config import Config
 from ..client.api_client import IvyBloomAPIClient
+from ..utils.printing import emit_json
 from ..utils.colors import get_console
 
 console = get_console()
@@ -88,7 +89,7 @@ def list(ctx, format, interactive):
             projects_data = client.list_projects()
         
         if format == 'json':
-            console.print(json.dumps(projects_data, indent=2))
+            emit_json(projects_data)
         else:
             if not projects_data:
                 console.print("[yellow]No projects found[/yellow]")
@@ -207,7 +208,7 @@ def info(ctx, project_id, format):
             project_data = client.get_project(project_id)
         
         if format == 'json':
-            console.print(json.dumps(project_data, indent=2))
+            emit_json(project_data)
         else:
             # Handle both project_id and id field names
             project_id = project_data.get('project_id') or project_data.get('id', 'Unknown')
@@ -264,7 +265,7 @@ def jobs(ctx, project_id, format):
             jobs_data = client.list_project_jobs(project_id)
         
         if format == 'json':
-            console.print(json.dumps(jobs_data, indent=2))
+            emit_json(jobs_data)
         else:
             if not jobs_data:
                 console.print(f"[yellow]No jobs found for project {project_id}[/yellow]")
