@@ -19,6 +19,7 @@ from ..utils.schema_loader import (
     build_json_schema,
 )
 from ..client.api_client import IvyBloomAPIClient
+from ..utils.printing import emit_json
 
 console = get_console()
 
@@ -109,7 +110,7 @@ def run(ctx, tool_name, parameters, project_id, job_title, wait, dry_run, show_s
                         "schema_hints": normalize_parameters_schema(schema_data),
                         "json_schema": build_json_schema(schema_data),
                     }
-                    console.print(json.dumps(payload, indent=2))
+                    emit_json(payload)
                 else:
                     _show_dry_run(tool_name, tool_params, project_id, job_title)
                 return
@@ -138,10 +139,10 @@ def run(ctx, tool_name, parameters, project_id, job_title, wait, dry_run, show_s
                     "schema_hints": normalize_parameters_schema(schema_data),
                     "json_schema": build_json_schema(schema_data),
                 }
-                console.print(json.dumps(verbose_payload, indent=2))
+                emit_json(verbose_payload)
                 return
             if output_format == 'json':
-                console.print(json.dumps(job_result, indent=2))
+                emit_json(job_result)
                 return
             elif output_format == 'yaml':
                 import yaml
