@@ -3,6 +3,7 @@ from __future__ import annotations
 from typing import Optional, Dict, Any, List, Tuple
 import webbrowser
 import json
+import sys
 
 try:
     from textual.app import App, ComposeResult
@@ -26,6 +27,7 @@ from .projects_service import ProjectsService
 from .screens import CommandPalette, PromptScreen, FiltersScreen, SplashScreen, ProjectPicker, HistorySelectScreen
 from .views import JobsView, DetailsView
 from .history import HistoryManager
+from .debug_logger import DebugLogger
 
 
 class IvyBloomTUI(App):
@@ -51,6 +53,14 @@ class IvyBloomTUI(App):
         align: center middle;
         height: 100%;
     }}
+
+    .welcome-art {{
+        color: {EARTH_TONES['sage_medium']};
+    }}
+
+    .welcome-loading {{
+        color: {EARTH_TONES['accent']};
+    }}
     """
 
     BINDINGS = [
@@ -98,16 +108,25 @@ class IvyBloomTUI(App):
         self._help_prev_renderable = None
 
         # Services
-        self._runner = CLIRunner(self.config)
-        self._artifacts = ArtifactsService(self._runner)
+        # Route debug to a file by default to avoid overlay; respect --debug flag
+        log_file = str(self.config.config_dir / "tui_debug.log") if bool(self.config.get("debug", False)) else None
+        self._debug_logger = DebugLogger(enabled=bool(self.config.get("debug", False)), prefix="TUI", log_path=log_file)
+        self._runner = CLIRunner(self.config, logger=self._debug_logger)
+        self._artifacts = ArtifactsService(self._runner, logger=self._debug_logger)
         self._structure = StructureService()
-        self._jobs = JobsService(self._runner)
+        self._jobs = JobsService(self._runner, logger=self._debug_logger)
         self._projects = ProjectsService(self._runner)
         self._history = HistoryManager(self.config)
 
         # Project picker state
         self._picker_open: bool = False
         self._project_pick_timer = None
+        # First boot toggle for optional early picker
+        self._first_boot: bool = True
+
+    # ------------------ Debug helper ------------------
+    def _debug(self, message: str) -> None:
+        self._debug_logger.debug(message)
 
     def compose(self) -> ComposeResult:
         if self.show_header:
@@ -164,6 +183,7 @@ class IvyBloomTUI(App):
         return False
 
     def on_mount(self) -> None:
+        self._debug("on_mount: initializing UI and starting boot sequence")
         # Configure jobs table columns (dense)
         self.jobs_table.clear()
         self.jobs_table.add_columns("Job ID", "Tool", "Status", "Result")
@@ -197,6 +217,7 @@ class IvyBloomTUI(App):
         try:
             if not getattr(self, "_splash_opened", False):  # type: ignore[attr-defined]
                 self._splash_opened = True  # type: ignore[attr-defined]
+                self._debug("_show_splash: displaying splash screen")
                 self.push_screen(SplashScreen("IvyBloom", "Starting up…"))
         except Exception:
             pass
@@ -205,44 +226,60 @@ class IvyBloomTUI(App):
         try:
             if getattr(self, "_splash_opened", False):  # type: ignore[attr-defined]
                 self._splash_opened = False  # type: ignore[attr-defined]
+                self._debug("_hide_splash: hiding splash screen")
                 self.pop_screen()
         except Exception:
             pass
 
     def _start_boot_sequence(self) -> None:
-        """Show splash for at least 5 seconds while connecting; then auth; then project pick; then load jobs."""
+        """Quick boot: probe connectivity, then proceed to auth/project selection without long delay."""
+        self._debug("_start_boot_sequence: probing connectivity and scheduling continue")
         # Kick off an initial connectivity probe
         try:
             self._probe_connectivity()
         except Exception:
             pass
-        # Continue boot after minimum splash duration
+        # Proceed almost immediately (keep a tiny delay to let UI settle)
         try:
-            self.set_timer(5, self._continue_boot_sequence)
+            self.set_timer(0.2, self._continue_boot_sequence)
         except Exception:
             # If timers fail, continue immediately
             self._continue_boot_sequence()
 
     def _continue_boot_sequence(self) -> None:
         # Require authentication first
+        self._debug("_continue_boot_sequence: checking authentication state")
         try:
             if not self.auth_manager.is_authenticated():
                 if self.details_summary:
                     self.details_summary.update("Please authenticate to continue (browser|device|link|paste API key).")
+                # Hide splash before interactive prompt to avoid modal stacking that blocks input
+                self._hide_splash()
+                self._debug("_continue_boot_sequence: not authenticated -> prompting for auth")
                 self.push_screen(PromptScreen("Authenticate (browser|device|link|or paste API key)", placeholder="browser"), self._on_auth_chosen)
                 return
         except Exception:
             # If auth manager errors, still try to prompt
+            # Hide splash before interactive prompt to avoid modal stacking that blocks input
+            self._hide_splash()
+            self._debug("_continue_boot_sequence: auth check errored -> prompting for auth")
             self.push_screen(PromptScreen("Authenticate (browser|device|link|or paste API key)", placeholder="browser"), self._on_auth_chosen)
             return
         # If authenticated, ensure project selection
+        self._debug("_continue_boot_sequence: already authenticated -> ensuring project selection")
         self.call_later(self._ensure_project_then_load)
+        # Safety net: try again shortly to ensure the picker opens if first attempt failed
+        try:
+            self.set_timer(2, self._ensure_project_pick)
+        except Exception:
+            pass
 
     def _on_auth_chosen(self, choice: Optional[str]) -> None:
         sel = (choice or "").strip()
         if not sel:
             # default to browser
             sel = "browser"
+        self._debug(f"_on_auth_chosen: selection='{sel}'")
         try:
             if sel.lower() in {"browser", "b"}:
                 text = self._run_cli_text(["auth", "login", "--browser"], timeout=600) or ""
@@ -255,9 +292,11 @@ class IvyBloomTUI(App):
                 text = self._run_cli_text(["auth", "login", "--api-key", sel], timeout=120) or ""
             if self.details_summary:
                 self.details_summary.update(text or "Authentication flow completed.")
+            self._debug("_on_auth_chosen: authentication flow finished, proceeding to project selection")
         except Exception as e:
             if self.details_summary:
                 self.details_summary.update(f"[red]Authentication failed: {e}[/red]")
+            self._debug(f"_on_auth_chosen: authentication failed: {e}")
             # Re-prompt
             self.push_screen(PromptScreen("Authenticate (browser|device|link|or paste API key)", placeholder="browser"), self._on_auth_chosen)
             return
@@ -266,19 +305,37 @@ class IvyBloomTUI(App):
 
     def _ensure_project_then_load(self) -> None:
         # If no project chosen, open picker; otherwise load jobs and hide splash once loaded
+        self._debug(f"_ensure_project_then_load: initial_project_id={self.initial_project_id}")
         if not self.initial_project_id:
             try:
+                self._debug("_ensure_project_then_load: listing projects via CLI")
                 projects = self._projects.list_projects()
+                self._debug(f"_ensure_project_then_load: projects_count={len(projects) if isinstance(projects, list) else 'N/A'}")
                 if projects:
                     self._picker_open = True
+                    # Hide splash before showing the project picker to ensure it's interactive
+                    self._hide_splash()
+                    self._debug("_ensure_project_then_load: opening ProjectPicker modal")
                     self.push_screen(ProjectPicker(projects), self._on_project_picked)
                     if self.details_summary:
                         self.details_summary.update("Select a project to continue…")
                     return
                 else:
+                    # No projects available; hide splash so the message is visible and app is usable
+                    self._hide_splash()
+                    self._debug("_ensure_project_then_load: no projects available")
                     if self.details_summary:
                         self.details_summary.update("No projects available. Create one in the web app.")
+                    # Re-attempt shortly instead of falling through
+                    try:
+                        self.set_timer(5, self._ensure_project_then_load)
+                    except Exception:
+                        pass
+                    return
             except Exception as e:
+                # On failure to load projects, hide splash so user can see the error and retry
+                self._hide_splash()
+                self._debug(f"_ensure_project_then_load: failed to list projects: {e}")
                 if self.details_summary:
                     self.details_summary.update(f"[red]Failed to load projects: {e}[/red]")
                 # Retry shortly
@@ -287,8 +344,29 @@ class IvyBloomTUI(App):
                 except Exception:
                     pass
                 return
+        else:
+            # If a prior selection exists but we want to force selection on first boot when debug is on
+            if getattr(self, "_first_boot", True) and bool(self.config.get("debug", False)):
+                try:
+                    projects = self._projects.list_projects()
+                    if projects:
+                        self._picker_open = True
+                        self._hide_splash()
+                        self._debug("_ensure_project_then_load: forcing ProjectPicker due to debug + first boot")
+                        self.push_screen(ProjectPicker(projects), self._on_project_picked)
+                        return
+                except Exception:
+                    pass
         # If we have a project, load jobs
+        self._debug(f"_ensure_project_then_load: project preset -> loading jobs for {self.initial_project_id}")
         self.call_later(self._load_jobs)
+        # If a project was pre-specified, we still want to give users a chance to switch early on first boot
+        if getattr(self, "_first_boot", True):
+            try:
+                self._first_boot = False  # type: ignore[attr-defined]
+                self.set_timer(0.5, self._ensure_project_pick)
+            except Exception:
+                pass
 
     # ------------------ Command Palette ------------------
     def action_open_palette(self) -> None:
@@ -329,7 +407,7 @@ class IvyBloomTUI(App):
             ("protein_stop_ascii", "Protein: Stop ASCII", "Stop protein ASCII view"),
             ("pick_project", "Project: Pick", "Select a project to focus"),
         ]
-        self.push_screen(CommandPalette(commands), self._on_palette_result)
+        self.push_screen(CommandPalette(commands, logger=self._debug_logger), self._on_palette_result)
 
     def _on_palette_result(self, result: Optional[str]) -> None:
         if not result:
@@ -510,18 +588,23 @@ class IvyBloomTUI(App):
         return jobs
 
     async def _load_jobs(self) -> None:
+        self._debug("_load_jobs: checking readiness")
         if not self._is_ready():
+            self._debug("_load_jobs: not ready (splash/picker/auth gating)")
             return
         self.jobs_offset = 0
         self.jobs_table.clear()
         try:
+            self._debug(f"_load_jobs: fetching jobs for project_id={self.initial_project_id}")
             jobs = self._jobs_view.load_initial(self.initial_project_id)
             self.jobs = jobs
         except Exception as e:
             if self.details_summary:
                 self.details_summary.update(f"[red]Failed to load jobs: {e}[/red]")
+            self._debug(f"_load_jobs: error {e}")
         finally:
             self._hide_splash()
+            self._update_status_bar()
 
     def _cmd_jobs_load_more(self) -> None:
         if not self._require_ready():
@@ -632,7 +715,7 @@ class IvyBloomTUI(App):
                 artifacts = data.get("artifacts") or []
             for art in artifacts:
                 if not isinstance(art, dict):
-                        continue
+                    continue
                 url = art.get("presigned_url") or art.get("url")
                 aType = str(art.get("artifact_type") or art.get("type") or "").lower()
                 if url and (any(t in aType for t in ["pdb", "sdf", "primary", "zip"])):
@@ -668,6 +751,7 @@ class IvyBloomTUI(App):
             self._connected = False
         finally:
             self._update_status_bar()
+            self._debug(f"_probe_connectivity: connected={self._connected}")
 
     def _update_status_bar(self) -> None:
         if not self.status_bar:
@@ -983,6 +1067,7 @@ class IvyBloomTUI(App):
     def _on_project_picked(self, project_id: Optional[str]) -> None:
         # Picker dismissed
         self._picker_open = False
+        self._debug(f"_on_project_picked: project_id={project_id}")
         if not project_id:
             # No selection; prompt again soon
             try:
@@ -996,10 +1081,26 @@ class IvyBloomTUI(App):
         # Show splash and load jobs now that we have a project
         self._splash_opened = False  # type: ignore[attr-defined]
         self._show_splash()
+        self._update_status_bar()
         self.call_later(self._load_jobs)
 
     def _ensure_project_pick(self) -> None:
-        if self.initial_project_id or self._picker_open:
+        if self._picker_open:
+            return
+        # If a project is already set, offer a quick switch on first boot
+        if self.initial_project_id and getattr(self, "_first_boot", False):
+            try:
+                projects = self._projects.list_projects()
+                if projects:
+                    self._picker_open = True
+                    self._hide_splash()
+                    self._debug("_ensure_project_pick: offering switch picker on first boot")
+                    self.push_screen(ProjectPicker(projects), self._on_project_picked)
+                    if self.details_summary:
+                        self.details_summary.update("Switch project? (Esc to keep current)")
+                    return
+            except Exception:
+                pass
             return
         try:
             projects = self._projects.list_projects()
