@@ -423,6 +423,13 @@ class AuthManager:
         # Prefer stored JWT token if available
         if self.get_auth_token():
             return True
+        # Consider OAuth tokens valid if present and not expired (auto-refresh may occur)
+        try:
+            tokens = self.get_valid_oauth_tokens()
+            if tokens and (tokens.get("access_token") or tokens.get("id_token")):
+                return True
+        except Exception:
+            pass
         # Fallback to API key
         return self.get_api_key() is not None
     
